tattl documentation
===================

TATTL (the *Totally Awesome Type-Aware TOML Loader*) is a library to deserialize data, particularly
application configuration, while validating types. It builds an instance of a given ``dataclass``
and checks the value of each field against its type annotations. It supports nested ``dataclass``
structures and modern type definitions.

For older versions of TATTL, use the version selector in the left sidebar.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reference
